
# THIS FILE IS GENERATED FROM SETUP.PY
short_version = '0.0.4'
version = '0.0.4'
full_version = '0.0.4.dev20160229200756'
git_revision = 'cc1ac11bf6f33faaea2e02bfe782e53e617c1f7c'
release = False

if not release:
    version = full_version
